@@ -10,7 +10,7 @@ namespace xs {
 template <> struct Typemap<panda::string> : TypemapBase<panda::string> {
     static inline panda::string in (SV* arg) {
         STRLEN len;
-        const char* data = SvPV_nomg(arg, len);
+        const char* data = SvPV_const(arg, len);
         return panda::string(data, len);
     }
     static inline Sv out (const panda::string& str, const Sv& = Sv()) { return Simple(str); }
@@ -19,7 +19,7 @@ template <> struct Typemap<panda::string> : TypemapBase<panda::string> {
 template <> struct Typemap<std::string> : TypemapBase<std::string> {
     static inline std::string in (SV* arg) {
         STRLEN len;
-        const char* data = SvPV_nomg(arg, len);
+        const char* data = SvPV_const(arg, len);
         return std::string(data, len);
     }
     static inline Sv out (const std::string& str, const Sv& = Sv()) { return Simple(panda::string_view(str.data(), str.length())); }
@@ -28,7 +28,7 @@ template <> struct Typemap<std::string> : TypemapBase<std::string> {
 template <> struct Typemap<panda::string_view> : TypemapBase<panda::string_view> {
     static inline panda::string_view in (SV* arg) {
         STRLEN len;
-        const char* data = SvPV_nomg(arg, len);
+        const char* data = SvPV_const(arg, len);
         return panda::string_view(data, len);
     }
     static inline Sv out (const panda::string_view& str, const Sv& = Sv()) { return Simple(str); }
